"use strict";
this.name        = "ecl_SAR_shipscript.js"; 
this.author      = "capt murphy"; 
this.copyright   = " 2012 capt murphy.";
this.licence     = "CC BY-NC-SA 3.0"; // see http://creativecommons.org/licenses/by-nc-sa/3.0/ for more info.
this.description = "shipscript for escape capsule locator comapatible search and rescue ships."; 
this.version     = "1.4.1";

// initialises arrays that are used to record entities attacking the SAR ship, and whether or not they have been warned of legal repercussions of attack and/or a penalty has already been applied for attack.
this.ecl_warn = new Array;
this.ecl_warned = new Array;
this.ecl_penalised = new Array;

this.ecl_chooseRoute = function() // called from AI - search and rescue ships may initially chose to head for witch point or planet on patrol.
{
 if (Math.random() > 0.5)
 {this.ship.reactToAIMessage("GO_TO_WP");}
 else {this.ship.reactToAIMessage("GO_TO_PLANET");}
}

this.ecl_findPods = function() // called from AI - looks for escape pods within 15 scanner ranges and if found calls function to set target.
{
 var targets = system.shipsWithPrimaryRole("escape-capsule",this.ship,this.ship.scannerRange*15);
 if (targets.length > 0)
 {this.ecl_setTargets(targets[0]);return;}
 this.ship.reactToAIMessage("NO_POD");
}

this.ecl_setTargets = function (target) // sends messages to AI depending on whether nearest identified pod is within scanner range or not. If near AI will try and scoop pod. If far ship will approach pod at injector speed.
{
  this.ship.target = target;
  if (this.ship.position.distanceTo(this.ship.target.position) > this.ship.scannerRange)
  {
	this.ship.fuel = 7;
	this.ship.reactToAIMessage("ESCAPEPOD_FOUND_FAR");
  }
  else {this.ship.reactToAIMessage("ESCAPEPOD_FOUND_NEAR");}
}
// gives a warning if attacked and applies bounty if attack continues
this.shipBeingAttacked = function (whom)
{
 if (this.ecl_warn.indexOf(whom) === -1) // if first attack by that entity add to array of entities to be warned if they attack again
 {
  this.ecl_warn.push(whom);
  return;
 }
 if (this.ecl_warn.indexOf(whom) !== -1 && this.ecl_warned.indexOf(whom) === -1) // if entity has attacked before, but hasn't been warned, issue warning and add to array of entities to be penalised if they attack again.
 {
  this.ship.commsMessage("Warning - Firing on an official SAR vessel is a crime. We are authorised to put a bounty on your head if you do not cease fire.",whom);
  this.ecl_warned.push(whom);
  return;
 }
 if (this.ecl_warned.indexOf(whom)!== -1 && this.ecl_penalised.indexOf(whom) === -1) // if entity has attacked before and been warned, but not penalised apply legal penalty and add to array of penalised entities.
 {
  this.ship.commsMessage("You were warned! A 75 credit bounty has been applied to your legal record!",whom);
  whom.bounty += 75;
  this.ecl_penalised.push(whom);
 }
}

this.shipAttackedWithMissile = function (missile, whom)
{
 if (whom)
 {this.shipBeingAttacked (whom);}
}
// if ship is killed by another entity and that entity has not been penalised for the attack already, apply penalty.
this.shipDied = function(whom, why)
{
  if (why === "energy damage" && whom)
  {
   if (this.ecl_penalised.indexOf(whom) === -1)
   {whom.bounty += 75;}
  }
}

 
 
 
  
  
   
  