"use strict";
this.name        = "escapePodLocator.js"; 
this.author      = "another_commander further development by capt murphy"; 
this.copyright   = " 20072012 the Oolite team.";
this.licence     = "CC BY-NC-SA 3.0"; // see http://creativecommons.org/licenses/by-nc-sa/3.0/ for more info.
this.description = "Upgrade to the IFF Scanner System and Advanced Space Compass. Shows escape pods in custom scanner colors and marks them on the Advanced Space Compass with an 'E'"; 
this.version     = "1.4.1";

// These variables control how far away escape pods will be detected as a multiple of normal scanner range. For example 'this.ecl_normalSpaceRange = 10;' will set the equipment to detect escape pods less than 10 x scanner range from the player in normal space. Range can be set independantly for normal and interstellar space. The default value of null (or 0) equates to infinite range. To effectively disable the equipment in interstellar space set this.ecl_interstellarSpaceRange = 0.000001;
this.ecl_normalSpaceRange = 100;
this.ecl_interstellarSpaceRange = 100;


// Checks if the range variables have been changed by another OXP and if so logs that info.
this.shipExitedWitchspace = this.shipLaunchedFromStation = function()
{
    if (this.ecl_normalSpaceRange)
	{log (this.name,"FOR INFO: Range in normal space has been modified by another OXP.")}
	if (this.ecl_interstellarSpaceRange)
	{log (this.name,"FOR INFO: Range in interstellar space has been modified by another OXP.")}
}
	

// starts the OXP's timer when the player launches.
this.shipWillLaunchFromStation = function()
{
    if (player.ship.equipmentStatus("EQ_ESCAPE_CAPSULE_LOCATOR") !== "EQUIPMENT_UNAVAILABLE" || player.ship.equipmentStatus("EQ_ESCAPE_CAPSULE_LOCATOR_DISABLED") !== "EQUIPMENT_UNAVAILABLE")
	{
		if (!this.ecl_mainTimer)
		{
			this.ecl_mainTimer = new Timer(this, this.ecl_mainChecks,5,5);
		}
		else
		{
			this.ecl_mainTimer.start();
		} 
	}
}

// called by timer every 5 seconds. If player is clean and has the equipment installed will call a function to check for any undetected pods (within range if defined) and assign them a beacon and custom scanner colours. If player is not clean will disable the equipment and remove all beacons and custom scanner colours. If equipment is disabled and player is now clean the equipment will be renabled.
this.ecl_mainChecks = function()
{
  if (player.ship.bounty === 0)
  {
    if (player.ship.equipmentStatus("EQ_ESCAPE_CAPSULE_LOCATOR") === "EQUIPMENT_OK")
    {this.ecl_updateBeacons();} 
    if (player.ship.equipmentStatus("EQ_ESCAPE_CAPSULE_LOCATOR_DISABLED") === "EQUIPMENT_OK")
	{
	 player.ship.removeEquipment("EQ_ESCAPE_CAPSULE_LOCATOR_DISABLED");
	 player.ship.awardEquipment("EQ_ESCAPE_CAPSULE_LOCATOR");
	 player.consoleMessage("Escape Pod Locator re-enabled.",5);
	}
	return;
  }
  if (player.ship.equipmentStatus("EQ_ESCAPE_CAPSULE_LOCATOR_DISABLED") !== "EQUIPMENT_OK" && player.ship.equipmentStatus("EQ_ESCAPE_CAPSULE_LOCATOR") === "EQUIPMENT_OK")
    {
	 player.ship.removeEquipment("EQ_ESCAPE_CAPSULE_LOCATOR");
	 player.ship.awardEquipment("EQ_ESCAPE_CAPSULE_LOCATOR_DISABLED");
	 this.ecl_removeAllBeacons(); // calls function to remove all beacons and custom scanner colours.
	 player.consoleMessage("Escape Pod Locator disabled. This equipment can only be used by Clean Pilots.",5);
	}
 }
 
 // called from timer every five seconds via this.ecl_mainChecks. Checks for pods (within range if defined) without beacons and spawns a beacon if necessary. If a range has been defined will also check for pods with a beacon that are now out of range and remove the beacon.
this.ecl_updateBeacons = function()
{
 var counter;
 var arrayLength;
 var range = false;
 // check to see if a finite range is defined and if so spawn / remove beacons as appropriate.
 if (system.isInterstellarSpace && this.ecl_interstellarSpaceRange)
 {range = this.ecl_interstellarSpaceRange * player.ship.scannerRange;}
 if (!system.isInterstellarSpace && this.ecl_normalSpaceRange)
 {range = this.ecl_normalSpaceRange * player.ship.scannerRange;}
 if (range)
 {
	var beaconsinRange = system.shipsWithPrimaryRole("ecl_escape_pod_beacon",player.ship,range); // array of all escape pod beacons within the defined range
	var podsinRange = system.shipsWithPrimaryRole("escape-capsule",player.ship,range);
	// array of all escape pods within the defined range
	var beacons = system.shipsWithPrimaryRole("ecl_escape_pod_beacon");
	// array of all escape pods beacons in universe
	var pods = system.shipsWithPrimaryRole("escape-capsule");
	// array of all escape pods in universe
	var beaconsinRangeTargets = new Array;
	arrayLength = beaconsinRange.length;
	for (counter = 0; counter < arrayLength ;counter++)
	{
	 if (beaconsinRange[counter].target)
	 {beaconsinRangeTargets.push(beaconsinRange[counter].target);}// creates array of all the pods with a beacon within the defined range
	}
	if (podsinRange.length !== beaconsinRangeTargets.length) // if there are pods in range without beacons....
	{
	 var podsNoBeacons = podsinRange.filter(function(value){return this.indexOf(value) === -1},beaconsinRangeTargets); // make an array of the pods in range without beacons and then spawn beacons for those pods.
	 if (podsNoBeacons.length > 0)
		{ 
			arrayLength = podsNoBeacons.length;
			for (counter = 0; counter < arrayLength ;counter++)
			{
			 this.ecl_spawnBeacon(podsNoBeacons[counter]);
			}
		}
	}
	if (beacons.length !== beaconsinRange.length) // if there are active beacons outside of the defined range....
	{
	 var beaconsForRemoval = beacons.filter(function(value){return this.indexOf(value) === -1},beaconsinRange); // make an array of those beacons that are out of range and then remove them
	 if (beaconsForRemoval.length > 0)
		{ 
			arrayLength = beaconsForRemoval.length;
			for (counter = 0; counter < arrayLength ;counter++)
			{
			 this.ecl_removeBeacon(beaconsForRemoval[counter]);
			}
		}
	}
 }
 // if no finite range just check for pods without beacons and spawn beacons as necessary.
 if (!range)
 {
	var beacons = system.shipsWithPrimaryRole("ecl_escape_pod_beacon");
	var pods = system.shipsWithPrimaryRole("escape-capsule");
	var beaconTargets = new Array;
	arrayLength = beacons.length;
	for (counter = 0; counter < arrayLength; counter ++)
	{
	 if (beacons[counter].target)
	 {beaconTargets.push(beacons[counter].target);} // create an array of pods with an associated beacon
	}
	if (pods.length !== beaconTargets.length) // if there are pods with no beacon.....
	    {
		 var podsNoBeacons = pods.filter(function(value){return this.indexOf(value) === -1},beaconTargets); // make an array of pods without a beacon and spawn beacons for those pods.
		 if (podsNoBeacons.length > 0)
		 { 
			arrayLength = podsNoBeacons.length;
			for (counter = 0; counter < arrayLength ;counter++)
			{
			 this.ecl_spawnBeacon(podsNoBeacons[counter]);
			}
		 }
		}
  }
}

// function to spawn a beacon and apply custom scanner colours to associated escape pod.
this.ecl_spawnBeacon = function(pod)
{
	if (!pod.isValid)
	{return;}
	var beacon = system.addShips("ecl_escape_pod_beacon",1,pod.position,50);
	if (beacon.length > 0)
	{
		beacon[0].target = pod; // attaches the beacon to it's pod.
		beacon[0].position = pod.position.add(pod.vectorUp.multiply(25)); // moves beacon to position 25m above pod.
		if (!system.isInterstellarSpace) // vary message depending on whether in interstellar space or not.
		{player.consoleMessage("Escape Pod distress signal detected. Signal source is marked 'E' on your compass.",5);}
		else {player.consoleMessage("Escape Pod distress signal detected.",5);}
		pod.scannerDisplayColor1 = "whiteColor";
		pod.scannerDisplayColor2 = "greenColor";
	}
}
// function to remove an individual beacon and custom scanner colours.
this.ecl_removeBeacon = function(beacon)
{   
	if (!beacon.isValid)
	{return;}
    if (beacon.target)
	{
		beacon.target.scannerDisplayColor1 = null;
		beacon.target.scannerDisplayColor2 = null;
	}
	beacon.remove(true);
	player.consoleMessage("Escape Pod distress signal lost.",5);
}

this.equipmentDamaged = function (equipment)
{
 if (equipment === "EQ_ESCAPE_CAPSULE_LOCATOR")
 {
	this.ecl_removeAllBeacons(); // calls function to remove all beacons and clear custom scanner colours.
	player.consoleMessage("Escape Pod Locator Damaged!",3);
	return;
 }
 if (equipment === "EQ_ESCAPE_CAPSULE_LOCATOR_DISABLED")// can't be damaged when disabled.
 {
  player.ship.setEquipmentStatus("EQ_ESCAPE_CAPSULE_LOCATOR_DISABLED","EQUIPMENT_OK");
 }
}

 // function to remove all beacons and custom scanner colours in event of equipment being disabled or damaged.
 this.ecl_removeAllBeacons = function()
{
    var counter;
	var arrayLength;
	var beacons = system.shipsWithPrimaryRole("ecl_escape_pod_beacon"); // array of all escape pod beacons in system.
	if (beacons.length > 0)
	{
	    arrayLength = beacons.length;
		for (counter = 0; counter < arrayLength ;counter++)
		{
		 this.ecl_removeBeacon(beacons[counter]);
		}

	}
}


// Event handler driven function to stop timer and remove beacons if player dies or docks.
this.shipDied = this.shipWillDockWithStation = function()
{
	if (this.ecl_mainTimer && this.ecl_mainTimer.isRunning)
		{
			this.ecl_mainTimer.stop();
			delete this.ecl_mainTimer;
			this.ecl_removeAllBeacons();
		}
}

// event handler driven function to allow equipment to be resold.
this.playerBoughtEquipment = function(equipmentKey)
{
	if(equipmentKey === "EQ_ESCAPE_CAPSULE_LOCATOR_REMOVAL")
		{
			player.ship.removeEquipment("EQ_ESCAPE_CAPSULE_LOCATOR");
			player.ship.removeEquipment("EQ_ESCAPE_CAPSULE_LOCATOR_REMOVAL");
			player.credits += (EquipmentInfo.infoForKey("EQ_ESCAPE_CAPSULE_LOCATOR").price * 0.1 * 0.6);
		}
}
